@@ -35,6 +35,9 @@ class DescribeProductsRequest(AbstractModel):
 
     @property
     def Limit(self):
+        """返回数量，默认为 20，最大值为 100。
+        :rtype: int
+        """
         return self._Limit
 
     @Limit.setter
@@ -43,6 +46,9 @@ class DescribeProductsRequest(AbstractModel):
 
     @property
     def Offset(self):
+        """偏移量，默认为 0。
+        :rtype: int
+        """
         return self._Offset
 
     @Offset.setter
@@ -83,6 +89,9 @@ class DescribeProductsResponse(AbstractModel):
 
     @property
     def Products(self):
+        """产品详细信息列表。
+        :rtype: list of RegionProduct
+        """
         return self._Products
 
     @Products.setter
@@ -91,6 +100,9 @@ class DescribeProductsResponse(AbstractModel):
 
     @property
     def TotalCount(self):
+        """产品总数量。
+        :rtype: int
+        """
         return self._TotalCount
 
     @TotalCount.setter
@@ -99,6 +111,9 @@ class DescribeProductsResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -134,6 +149,9 @@ class DescribeRegionsRequest(AbstractModel):
 
     @property
     def Product(self):
+        """待查询产品的名称，例如cvm，具体取值请查询DescribeProducts接口
+        :rtype: str
+        """
         return self._Product
 
     @Product.setter
@@ -142,6 +160,9 @@ class DescribeRegionsRequest(AbstractModel):
 
     @property
     def Scene(self):
+        """不传或者0表示不查询【可选业务白名单】，1表示查询【可选业务白名单】，该参数设置了1，只有在业务白名单查不到情况下，才会查该白名单
+        :rtype: int
+        """
         return self._Scene
 
     @Scene.setter
@@ -182,6 +203,9 @@ class DescribeRegionsResponse(AbstractModel):
 
     @property
     def TotalCount(self):
+        """地域数量
+        :rtype: int
+        """
         return self._TotalCount
 
     @TotalCount.setter
@@ -190,6 +214,9 @@ class DescribeRegionsResponse(AbstractModel):
 
     @property
     def RegionSet(self):
+        """地域列表信息
+        :rtype: list of RegionInfo
+        """
         return self._RegionSet
 
     @RegionSet.setter
@@ -198,6 +225,9 @@ class DescribeRegionsResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -233,6 +263,9 @@ class DescribeZonesRequest(AbstractModel):
 
     @property
     def Product(self):
+        """待查询产品的名称，例如cvm，具体取值请查询DescribeProducts接口
+        :rtype: str
+        """
         return self._Product
 
     @Product.setter
@@ -241,6 +274,9 @@ class DescribeZonesRequest(AbstractModel):
 
     @property
     def Scene(self):
+        """不传或者0表示不查询【可选业务白名单】，1表示查询【可选业务白名单】，该参数设置了1，只有在业务白名单查不到情况下，才会查该白名单
+        :rtype: int
+        """
         return self._Scene
 
     @Scene.setter
@@ -281,6 +317,9 @@ class DescribeZonesResponse(AbstractModel):
 
     @property
     def TotalCount(self):
+        """可用区数量。
+        :rtype: int
+        """
         return self._TotalCount
 
     @TotalCount.setter
@@ -289,6 +328,9 @@ class DescribeZonesResponse(AbstractModel):
 
     @property
     def ZoneSet(self):
+        """可用区列表信息。
+        :rtype: list of ZoneInfo
+        """
         return self._ZoneSet
 
     @ZoneSet.setter
@@ -297,6 +339,9 @@ class DescribeZonesResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -351,6 +396,9 @@ class RegionInfo(AbstractModel):
 
     @property
     def Region(self):
+        """地域名称，例如，ap-guangzhou
+        :rtype: str
+        """
         return self._Region
 
     @Region.setter
@@ -359,6 +407,9 @@ class RegionInfo(AbstractModel):
 
     @property
     def RegionName(self):
+        """地域描述，例如，华南地区(广州)
+        :rtype: str
+        """
         return self._RegionName
 
     @RegionName.setter
@@ -367,6 +418,9 @@ class RegionInfo(AbstractModel):
 
     @property
     def RegionState(self):
+        """地域是否可用状态
+        :rtype: str
+        """
         return self._RegionState
 
     @RegionState.setter
@@ -375,6 +429,10 @@ class RegionInfo(AbstractModel):
 
     @property
     def RegionTypeMC(self):
+        """控制台类型，api调用时默认null
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._RegionTypeMC
 
     @RegionTypeMC.setter
@@ -383,6 +441,10 @@ class RegionInfo(AbstractModel):
 
     @property
     def LocationMC(self):
+        """不同语言的地区
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LocationMC
 
     @LocationMC.setter
@@ -391,6 +453,10 @@ class RegionInfo(AbstractModel):
 
     @property
     def RegionNameMC(self):
+        """控制台展示的地域描述
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._RegionNameMC
 
     @RegionNameMC.setter
@@ -399,6 +465,10 @@ class RegionInfo(AbstractModel):
 
     @property
     def RegionIdMC(self):
+        """1
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._RegionIdMC
 
     @RegionIdMC.setter
@@ -438,6 +508,9 @@ class RegionProduct(AbstractModel):
 
     @property
     def Name(self):
+        """产品名称，如cvm
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -495,7 +568,6 @@ class ZoneInfo(AbstractModel):
 <li> ap-shanghai-5 </li>
 <li> ap-mumbai-1 </li>
 <li> ap-mumbai-2 </li>
-<li> eu-moscow-1 </li>
 <li> ap-beijing-1 </li>
 <li> ap-beijing-2 </li>
 <li> ap-beijing-3 </li>
@@ -504,7 +576,6 @@ class ZoneInfo(AbstractModel):
 <li> na-siliconvalley-1 </li>
 <li> na-siliconvalley-2 </li>
 <li> eu-frankfurt-1 </li>
-<li> na-toronto-1 </li>
 <li> na-ashburn-1 </li>
 <li> na-ashburn-2 </li>
 <li> ap-nanjing-1 </li>
@@ -548,6 +619,51 @@ class ZoneInfo(AbstractModel):
 
     @property
     def Zone(self):
+        """可用区名称，例如，ap-guangzhou-3
+全网可用区名称如下：
+<li> ap-chongqing-1 </li>
+<li> ap-seoul-1 </li>
+<li> ap-seoul-2 </li>
+<li> ap-chengdu-1 </li>
+<li> ap-chengdu-2 </li>
+<li> ap-hongkong-1 </li>
+<li> ap-hongkong-2 </li>
+<li> ap-shenzhen-fsi-1 </li>
+<li> ap-shenzhen-fsi-2 </li>
+<li> ap-shenzhen-fsi-3 </li>
+<li> ap-guangzhou-1（售罄）</li>
+<li> ap-guangzhou-2（售罄）</li>
+<li> ap-guangzhou-3 </li>
+<li> ap-guangzhou-4 </li>
+<li> ap-guangzhou-6 </li>
+<li> ap-tokyo-1 </li>
+<li> ap-singapore-1 </li>
+<li> ap-singapore-2 </li>
+<li> ap-shanghai-fsi-1 </li>
+<li> ap-shanghai-fsi-2 </li>
+<li> ap-shanghai-fsi-3 </li>
+<li> ap-bangkok-1 </li>
+<li> ap-shanghai-1（售罄） </li>
+<li> ap-shanghai-2 </li>
+<li> ap-shanghai-3 </li>
+<li> ap-shanghai-4 </li>
+<li> ap-shanghai-5 </li>
+<li> ap-mumbai-1 </li>
+<li> ap-mumbai-2 </li>
+<li> ap-beijing-1 </li>
+<li> ap-beijing-2 </li>
+<li> ap-beijing-3 </li>
+<li> ap-beijing-4 </li>
+<li> ap-beijing-5 </li>
+<li> na-siliconvalley-1 </li>
+<li> na-siliconvalley-2 </li>
+<li> eu-frankfurt-1 </li>
+<li> na-ashburn-1 </li>
+<li> na-ashburn-2 </li>
+<li> ap-nanjing-1 </li>
+<li> ap-nanjing-2 </li>
+        :rtype: str
+        """
         return self._Zone
 
     @Zone.setter
@@ -556,6 +672,9 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ZoneName(self):
+        """可用区描述，例如，广州三区
+        :rtype: str
+        """
         return self._ZoneName
 
     @ZoneName.setter
@@ -564,6 +683,9 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ZoneId(self):
+        """可用区ID
+        :rtype: str
+        """
         return self._ZoneId
 
     @ZoneId.setter
@@ -572,6 +694,9 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ZoneState(self):
+        """可用区状态，包含AVAILABLE和UNAVAILABLE。AVAILABLE代表可用，UNAVAILABLE代表不可用。
+        :rtype: str
+        """
         return self._ZoneState
 
     @ZoneState.setter
@@ -580,6 +705,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ParentZone(self):
+        """父级zone
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ParentZone
 
     @ParentZone.setter
@@ -588,6 +717,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ParentZoneId(self):
+        """父级可用区ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ParentZoneId
 
     @ParentZoneId.setter
@@ -596,6 +729,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ParentZoneName(self):
+        """父级可用区描述
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ParentZoneName
 
     @ParentZoneName.setter
@@ -604,6 +741,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ZoneType(self):
+        """zone类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ZoneType
 
     @ZoneType.setter
@@ -612,6 +753,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def MachineRoomTypeMC(self):
+        """控制台类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._MachineRoomTypeMC
 
     @MachineRoomTypeMC.setter
@@ -620,6 +765,10 @@ class ZoneInfo(AbstractModel):
 
     @property
     def ZoneIdMC(self):
+        """和ZoneId一样，适用于控制台调用。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ZoneIdMC
 
     @ZoneIdMC.setter
